summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmplaneedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmplaneedit.h')
-rw-r--r--kpovmodeler/pmplaneedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmplaneedit.h b/kpovmodeler/pmplaneedit.h
index 80e72e47..0b4c3f3f 100644
--- a/kpovmodeler/pmplaneedit.h
+++ b/kpovmodeler/pmplaneedit.h
@@ -34,12 +34,13 @@ class TQCheckBox;
class PMPlaneEdit : public PMSolidObjectEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMPlaneEdit with parent and name
*/
- PMPlaneEdit( TQWidget* parent, const char* name = 0 );
+ PMPlaneEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -34,12 +34,13 @@ class TQCheckBox;
public:
/**
- * Creates a PMPlaneEdit with parent and name
+ * Creates a PMPlaneEdit with tqparent and name
*/